@@ -33,7 +33,7 @@ from calculate.lib.utils.tools import imap_regexp
 from more import WorkPalette, ParameterWindow, get_system_rgb
 
 from more import get_sid, ClientServiceThread, show_msg, TaskWidget, ErrorWgt,\
-                 ResultLayout, get_view_params, get_icon
+                 ResultLayout, get_view_params, get_icon, dpivalue
 from more import LabelWordWrap as Label
 from SelectTable import SelectedTableWidget
 
@@ -1118,7 +1118,7 @@ class ButtonDialog(qt.QWidget):
 
         minimum = qt.QSizePolicy.Fixed
         self.setSizePolicy(minimum, minimum)
-        self.setFixedHeight(32)
+        self.setFixedHeight(dpivalue(32))
         self.init(item)
 
     def init(self, item):
@@ -1139,7 +1139,7 @@ class ButtonDialog(qt.QWidget):
             button.setShortcut(qt.QKeySequence(shortcut))
         button.clicked.connect(self.send(answer, label))
         button.setFixedWidth(self.button_size)
-        button.setFixedHeight(32)
+        button.setFixedHeight(dpivalue(32))
         self.layout.addWidget(button)
 
     def send(self, answer, human_answer=None):
