@@ -320,7 +320,7 @@ class FrameConnection(qt.QWidget):
                 # check passwd private_key
                 import M2Crypto
                 bio = M2Crypto.BIO.openfile(CERT_KEY)
-                rsa = M2Crypto.m2.rsa_read_key(bio._ptr(),lambda *unused: None)
+                rsa = M2Crypto.m2.rsa_read_key(bio._ptr(),lambda *unused: "")
                 if re_passwd != False:
                     self.str_passwd = re_passwd
                 if not rsa and not self.str_passwd and auto:
